# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/consensus/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.libs.bits import types_pb2 as tendermint_dot_libs_dot_bits_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/consensus/types.proto\x12\x14tendermint.consensus\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/libs/bits/types.proto\"x\n\x0cNewRoundStep\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\r\x12 \n\x18seconds_since_start_time\x18\x04 \x01(\x03\x12\x19\n\x11last_commit_round\x18\x05 \x01(\x05\"\xbc\x01\n\rNewValidBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x44\n\x15\x62lock_part_set_header\x18\x03 \x01(\x0b\x32\x1f.tendermint.types.PartSetHeaderB\x04\xc8\xde\x1f\x00\x12\x33\n\x0b\x62lock_parts\x18\x04 \x01(\x0b\x32\x1e.tendermint.libs.bits.BitArray\x12\x11\n\tis_commit\x18\x05 \x01(\x08\">\n\x08Proposal\x12\x32\n\x08proposal\x18\x01 \x01(\x0b\x32\x1a.tendermint.types.ProposalB\x04\xc8\xde\x1f\x00\"u\n\x0bProposalPOL\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x1a\n\x12proposal_pol_round\x18\x02 \x01(\x05\x12:\n\x0cproposal_pol\x18\x03 \x01(\x0b\x32\x1e.tendermint.libs.bits.BitArrayB\x04\xc8\xde\x1f\x00\"V\n\tBlockPart\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12*\n\x04part\x18\x03 \x01(\x0b\x32\x16.tendermint.types.PartB\x04\xc8\xde\x1f\x00\",\n\x04Vote\x12$\n\x04vote\x18\x01 \x01(\x0b\x32\x16.tendermint.types.Vote\"f\n\x07HasVote\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\r\n\x05index\x18\x04 \x01(\x05\"\x9a\x01\n\x0cVoteSetMaj23\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12<\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\"\xce\x01\n\x0bVoteSetBits\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12<\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x33\n\x05votes\x18\x05 \x01(\x0b\x32\x1e.tendermint.libs.bits.BitArrayB\x04\xc8\xde\x1f\x00\"\x8d\x04\n\x07Message\x12<\n\x0enew_round_step\x18\x01 \x01(\x0b\x32\".tendermint.consensus.NewRoundStepH\x00\x12>\n\x0fnew_valid_block\x18\x02 \x01(\x0b\x32#.tendermint.consensus.NewValidBlockH\x00\x12\x32\n\x08proposal\x18\x03 \x01(\x0b\x32\x1e.tendermint.consensus.ProposalH\x00\x12\x39\n\x0cproposal_pol\x18\x04 \x01(\x0b\x32!.tendermint.consensus.ProposalPOLH\x00\x12\x35\n\nblock_part\x18\x05 \x01(\x0b\x32\x1f.tendermint.consensus.BlockPartH\x00\x12*\n\x04vote\x18\x06 \x01(\x0b\x32\x1a.tendermint.consensus.VoteH\x00\x12\x31\n\x08has_vote\x18\x07 \x01(\x0b\x32\x1d.tendermint.consensus.HasVoteH\x00\x12<\n\x0evote_set_maj23\x18\x08 \x01(\x0b\x32\".tendermint.consensus.VoteSetMaj23H\x00\x12:\n\rvote_set_bits\x18\t \x01(\x0b\x32!.tendermint.consensus.VoteSetBitsH\x00\x42\x05\n\x03sumB9Z7github.com/cometbft/cometbft/proto/tendermint/consensusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.consensus.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cometbft/cometbft/proto/tendermint/consensus'
  _NEWVALIDBLOCK.fields_by_name['block_part_set_header']._options = None
  _NEWVALIDBLOCK.fields_by_name['block_part_set_header']._serialized_options = b'\310\336\037\000'
  _PROPOSAL.fields_by_name['proposal']._options = None
  _PROPOSAL.fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _PROPOSALPOL.fields_by_name['proposal_pol']._options = None
  _PROPOSALPOL.fields_by_name['proposal_pol']._serialized_options = b'\310\336\037\000'
  _BLOCKPART.fields_by_name['part']._options = None
  _BLOCKPART.fields_by_name['part']._serialized_options = b'\310\336\037\000'
  _VOTESETMAJ23.fields_by_name['block_id']._options = None
  _VOTESETMAJ23.fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _VOTESETBITS.fields_by_name['block_id']._options = None
  _VOTESETBITS.fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _VOTESETBITS.fields_by_name['votes']._options = None
  _VOTESETBITS.fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_NEWROUNDSTEP']._serialized_start=144
  _globals['_NEWROUNDSTEP']._serialized_end=264
  _globals['_NEWVALIDBLOCK']._serialized_start=267
  _globals['_NEWVALIDBLOCK']._serialized_end=455
  _globals['_PROPOSAL']._serialized_start=457
  _globals['_PROPOSAL']._serialized_end=519
  _globals['_PROPOSALPOL']._serialized_start=521
  _globals['_PROPOSALPOL']._serialized_end=638
  _globals['_BLOCKPART']._serialized_start=640
  _globals['_BLOCKPART']._serialized_end=726
  _globals['_VOTE']._serialized_start=728
  _globals['_VOTE']._serialized_end=772
  _globals['_HASVOTE']._serialized_start=774
  _globals['_HASVOTE']._serialized_end=876
  _globals['_VOTESETMAJ23']._serialized_start=879
  _globals['_VOTESETMAJ23']._serialized_end=1033
  _globals['_VOTESETBITS']._serialized_start=1036
  _globals['_VOTESETBITS']._serialized_end=1242
  _globals['_MESSAGE']._serialized_start=1245
  _globals['_MESSAGE']._serialized_end=1770
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from injective.stream.v1beta1 import query_pb2 as injective_dot_stream_dot_v1beta1_dot_query__pb2


class StreamStub(object):
    """ChainStream defines the gRPC streaming service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Stream = channel.unary_stream(
                '/injective.stream.v1beta1.Stream/Stream',
                request_serializer=injective_dot_stream_dot_v1beta1_dot_query__pb2.StreamRequest.SerializeToString,
                response_deserializer=injective_dot_stream_dot_v1beta1_dot_query__pb2.StreamResponse.FromString,
                )


class StreamServicer(object):
    """ChainStream defines the gRPC streaming service.
    """

    def Stream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Stream': grpc.unary_stream_rpc_method_handler(
                    servicer.Stream,
                    request_deserializer=injective_dot_stream_dot_v1beta1_dot_query__pb2.StreamRequest.FromString,
                    response_serializer=injective_dot_stream_dot_v1beta1_dot_query__pb2.StreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.stream.v1beta1.Stream', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Stream(object):
    """ChainStream defines the gRPC streaming service.
    """

    @staticmethod
    def Stream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective.stream.v1beta1.Stream/Stream',
            injective_dot_stream_dot_v1beta1_dot_query__pb2.StreamRequest.SerializeToString,
            injective_dot_stream_dot_v1beta1_dot_query__pb2.StreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/group/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.group.v1 import types_pb2 as cosmos_dot_group_dot_v1_dot_types__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/group/v1/query.proto\x12\x0f\x63osmos.group.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x63osmos/group/v1/types.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\")\n\x15QueryGroupInfoRequest\x12\x10\n\x08group_id\x18\x01 \x01(\x04\"B\n\x16QueryGroupInfoResponse\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.cosmos.group.v1.GroupInfo\"H\n\x1bQueryGroupPolicyInfoRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"N\n\x1cQueryGroupPolicyInfoResponse\x12.\n\x04info\x18\x01 \x01(\x0b\x32 .cosmos.group.v1.GroupPolicyInfo\"h\n\x18QueryGroupMembersRequest\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x87\x01\n\x19QueryGroupMembersResponse\x12-\n\x07members\x18\x01 \x03(\x0b\x32\x1c.cosmos.group.v1.GroupMember\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x80\x01\n\x19QueryGroupsByAdminRequest\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x85\x01\n\x1aQueryGroupsByAdminResponse\x12*\n\x06groups\x18\x01 \x03(\x0b\x32\x1a.cosmos.group.v1.GroupInfo\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"p\n QueryGroupPoliciesByGroupRequest\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9a\x01\n!QueryGroupPoliciesByGroupResponse\x12\x38\n\x0egroup_policies\x18\x01 \x03(\x0b\x32 .cosmos.group.v1.GroupPolicyInfo\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x87\x01\n QueryGroupPoliciesByAdminRequest\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9a\x01\n!QueryGroupPoliciesByAdminResponse\x12\x38\n\x0egroup_policies\x18\x01 \x03(\x0b\x32 .cosmos.group.v1.GroupPolicyInfo\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"+\n\x14QueryProposalRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"D\n\x15QueryProposalResponse\x12+\n\x08proposal\x18\x01 \x01(\x0b\x32\x19.cosmos.group.v1.Proposal\"\x8b\x01\n\"QueryProposalsByGroupPolicyRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x90\x01\n#QueryProposalsByGroupPolicyResponse\x12,\n\tproposals\x18\x01 \x03(\x0b\x32\x19.cosmos.group.v1.Proposal\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"_\n\x1fQueryVoteByProposalVoterRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"G\n QueryVoteByProposalVoterResponse\x12#\n\x04vote\x18\x01 \x01(\x0b\x32\x15.cosmos.group.v1.Vote\"n\n\x1bQueryVotesByProposalRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x81\x01\n\x1cQueryVotesByProposalResponse\x12$\n\x05votes\x18\x01 \x03(\x0b\x32\x15.cosmos.group.v1.Vote\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x7f\n\x18QueryVotesByVoterRequest\x12\'\n\x05voter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"~\n\x19QueryVotesByVoterResponse\x12$\n\x05votes\x18\x01 \x03(\x0b\x32\x15.cosmos.group.v1.Vote\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x83\x01\n\x1aQueryGroupsByMemberRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x86\x01\n\x1bQueryGroupsByMemberResponse\x12*\n\x06groups\x18\x01 \x03(\x0b\x32\x1a.cosmos.group.v1.GroupInfo\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\".\n\x17QueryTallyResultRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"R\n\x18QueryTallyResultResponse\x12\x36\n\x05tally\x18\x01 \x01(\x0b\x32\x1c.cosmos.group.v1.TallyResultB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"P\n\x12QueryGroupsRequest\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"~\n\x13QueryGroupsResponse\x12*\n\x06groups\x18\x01 \x03(\x0b\x32\x1a.cosmos.group.v1.GroupInfo\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xfb\x11\n\x05Query\x12\x8c\x01\n\tGroupInfo\x12&.cosmos.group.v1.QueryGroupInfoRequest\x1a\'.cosmos.group.v1.QueryGroupInfoResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/group/v1/group_info/{group_id}\x12\xa4\x01\n\x0fGroupPolicyInfo\x12,.cosmos.group.v1.QueryGroupPolicyInfoRequest\x1a-.cosmos.group.v1.QueryGroupPolicyInfoResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/group/v1/group_policy_info/{address}\x12\x98\x01\n\x0cGroupMembers\x12).cosmos.group.v1.QueryGroupMembersRequest\x1a*.cosmos.group.v1.QueryGroupMembersResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/group/v1/group_members/{group_id}\x12\x9a\x01\n\rGroupsByAdmin\x12*.cosmos.group.v1.QueryGroupsByAdminRequest\x1a+.cosmos.group.v1.QueryGroupsByAdminResponse\"0\x82\xd3\xe4\x93\x02*\x12(/cosmos/group/v1/groups_by_admin/{admin}\x12\xba\x01\n\x14GroupPoliciesByGroup\x12\x31.cosmos.group.v1.QueryGroupPoliciesByGroupRequest\x1a\x32.cosmos.group.v1.QueryGroupPoliciesByGroupResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/group/v1/group_policies_by_group/{group_id}\x12\xb7\x01\n\x14GroupPoliciesByAdmin\x12\x31.cosmos.group.v1.QueryGroupPoliciesByAdminRequest\x1a\x32.cosmos.group.v1.QueryGroupPoliciesByAdminResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/group/v1/group_policies_by_admin/{admin}\x12\x8a\x01\n\x08Proposal\x12%.cosmos.group.v1.QueryProposalRequest\x1a&.cosmos.group.v1.QueryProposalResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/group/v1/proposal/{proposal_id}\x12\xc1\x01\n\x16ProposalsByGroupPolicy\x12\x33.cosmos.group.v1.QueryProposalsByGroupPolicyRequest\x1a\x34.cosmos.group.v1.QueryProposalsByGroupPolicyResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/group/v1/proposals_by_group_policy/{address}\x12\xc1\x01\n\x13VoteByProposalVoter\x12\x30.cosmos.group.v1.QueryVoteByProposalVoterRequest\x1a\x31.cosmos.group.v1.QueryVoteByProposalVoterResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cosmos/group/v1/vote_by_proposal_voter/{proposal_id}/{voter}\x12\xa8\x01\n\x0fVotesByProposal\x12,.cosmos.group.v1.QueryVotesByProposalRequest\x1a-.cosmos.group.v1.QueryVotesByProposalResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/group/v1/votes_by_proposal/{proposal_id}\x12\x96\x01\n\x0cVotesByVoter\x12).cosmos.group.v1.QueryVotesByVoterRequest\x1a*.cosmos.group.v1.QueryVotesByVoterResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/group/v1/votes_by_voter/{voter}\x12\xa0\x01\n\x0eGroupsByMember\x12+.cosmos.group.v1.QueryGroupsByMemberRequest\x1a,.cosmos.group.v1.QueryGroupsByMemberResponse\"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/group/v1/groups_by_member/{address}\x12\x9a\x01\n\x0bTallyResult\x12(.cosmos.group.v1.QueryTallyResultRequest\x1a).cosmos.group.v1.QueryTallyResultResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./cosmos/group/v1/proposals/{proposal_id}/tally\x12t\n\x06Groups\x12#.cosmos.group.v1.QueryGroupsRequest\x1a$.cosmos.group.v1.QueryGroupsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/cosmos/group/v1/groupsB&Z$github.com/cosmos/cosmos-sdk/x/groupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/group'
  _QUERYGROUPPOLICYINFOREQUEST.fields_by_name['address']._options = None
  _QUERYGROUPPOLICYINFOREQUEST.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYGROUPSBYADMINREQUEST.fields_by_name['admin']._options = None
  _QUERYGROUPSBYADMINREQUEST.fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYGROUPPOLICIESBYADMINREQUEST.fields_by_name['admin']._options = None
  _QUERYGROUPPOLICIESBYADMINREQUEST.fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYPROPOSALSBYGROUPPOLICYREQUEST.fields_by_name['address']._options = None
  _QUERYPROPOSALSBYGROUPPOLICYREQUEST.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYVOTEBYPROPOSALVOTERREQUEST.fields_by_name['voter']._options = None
  _QUERYVOTEBYPROPOSALVOTERREQUEST.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYVOTESBYVOTERREQUEST.fields_by_name['voter']._options = None
  _QUERYVOTESBYVOTERREQUEST.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYGROUPSBYMEMBERREQUEST.fields_by_name['address']._options = None
  _QUERYGROUPSBYMEMBERREQUEST.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYTALLYRESULTRESPONSE.fields_by_name['tally']._options = None
  _QUERYTALLYRESULTRESPONSE.fields_by_name['tally']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERY.methods_by_name['GroupInfo']._options = None
  _QUERY.methods_by_name['GroupInfo']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/group/v1/group_info/{group_id}'
  _QUERY.methods_by_name['GroupPolicyInfo']._options = None
  _QUERY.methods_by_name['GroupPolicyInfo']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/group/v1/group_policy_info/{address}'
  _QUERY.methods_by_name['GroupMembers']._options = None
  _QUERY.methods_by_name['GroupMembers']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/group/v1/group_members/{group_id}'
  _QUERY.methods_by_name['GroupsByAdmin']._options = None
  _QUERY.methods_by_name['GroupsByAdmin']._serialized_options = b'\202\323\344\223\002*\022(/cosmos/group/v1/groups_by_admin/{admin}'
  _QUERY.methods_by_name['GroupPoliciesByGroup']._options = None
  _QUERY.methods_by_name['GroupPoliciesByGroup']._serialized_options = b'\202\323\344\223\0025\0223/cosmos/group/v1/group_policies_by_group/{group_id}'
  _QUERY.methods_by_name['GroupPoliciesByAdmin']._options = None
  _QUERY.methods_by_name['GroupPoliciesByAdmin']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/group/v1/group_policies_by_admin/{admin}'
  _QUERY.methods_by_name['Proposal']._options = None
  _QUERY.methods_by_name['Proposal']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/group/v1/proposal/{proposal_id}'
  _QUERY.methods_by_name['ProposalsByGroupPolicy']._options = None
  _QUERY.methods_by_name['ProposalsByGroupPolicy']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/group/v1/proposals_by_group_policy/{address}'
  _QUERY.methods_by_name['VoteByProposalVoter']._options = None
  _QUERY.methods_by_name['VoteByProposalVoter']._serialized_options = b'\202\323\344\223\002?\022=/cosmos/group/v1/vote_by_proposal_voter/{proposal_id}/{voter}'
  _QUERY.methods_by_name['VotesByProposal']._options = None
  _QUERY.methods_by_name['VotesByProposal']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/group/v1/votes_by_proposal/{proposal_id}'
  _QUERY.methods_by_name['VotesByVoter']._options = None
  _QUERY.methods_by_name['VotesByVoter']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/group/v1/votes_by_voter/{voter}'
  _QUERY.methods_by_name['GroupsByMember']._options = None
  _QUERY.methods_by_name['GroupsByMember']._serialized_options = b'\202\323\344\223\002-\022+/cosmos/group/v1/groups_by_member/{address}'
  _QUERY.methods_by_name['TallyResult']._options = None
  _QUERY.methods_by_name['TallyResult']._serialized_options = b'\202\323\344\223\0020\022./cosmos/group/v1/proposals/{proposal_id}/tally'
  _QUERY.methods_by_name['Groups']._options = None
  _QUERY.methods_by_name['Groups']._serialized_options = b'\202\323\344\223\002\031\022\027/cosmos/group/v1/groups'
  _globals['_QUERYGROUPINFOREQUEST']._serialized_start=219
  _globals['_QUERYGROUPINFOREQUEST']._serialized_end=260
  _globals['_QUERYGROUPINFORESPONSE']._serialized_start=262
  _globals['_QUERYGROUPINFORESPONSE']._serialized_end=328
  _globals['_QUERYGROUPPOLICYINFOREQUEST']._serialized_start=330
  _globals['_QUERYGROUPPOLICYINFOREQUEST']._serialized_end=402
  _globals['_QUERYGROUPPOLICYINFORESPONSE']._serialized_start=404
  _globals['_QUERYGROUPPOLICYINFORESPONSE']._serialized_end=482
  _globals['_QUERYGROUPMEMBERSREQUEST']._serialized_start=484
  _globals['_QUERYGROUPMEMBERSREQUEST']._serialized_end=588
  _globals['_QUERYGROUPMEMBERSRESPONSE']._serialized_start=591
  _globals['_QUERYGROUPMEMBERSRESPONSE']._serialized_end=726
  _globals['_QUERYGROUPSBYADMINREQUEST']._serialized_start=729
  _globals['_QUERYGROUPSBYADMINREQUEST']._serialized_end=857
  _globals['_QUERYGROUPSBYADMINRESPONSE']._serialized_start=860
  _globals['_QUERYGROUPSBYADMINRESPONSE']._serialized_end=993
  _globals['_QUERYGROUPPOLICIESBYGROUPREQUEST']._serialized_start=995
  _globals['_QUERYGROUPPOLICIESBYGROUPREQUEST']._serialized_end=1107
  _globals['_QUERYGROUPPOLICIESBYGROUPRESPONSE']._serialized_start=1110
  _globals['_QUERYGROUPPOLICIESBYGROUPRESPONSE']._serialized_end=1264
  _globals['_QUERYGROUPPOLICIESBYADMINREQUEST']._serialized_start=1267
  _globals['_QUERYGROUPPOLICIESBYADMINREQUEST']._serialized_end=1402
  _globals['_QUERYGROUPPOLICIESBYADMINRESPONSE']._serialized_start=1405
  _globals['_QUERYGROUPPOLICIESBYADMINRESPONSE']._serialized_end=1559
  _globals['_QUERYPROPOSALREQUEST']._serialized_start=1561
  _globals['_QUERYPROPOSALREQUEST']._serialized_end=1604
  _globals['_QUERYPROPOSALRESPONSE']._serialized_start=1606
  _globals['_QUERYPROPOSALRESPONSE']._serialized_end=1674
  _globals['_QUERYPROPOSALSBYGROUPPOLICYREQUEST']._serialized_start=1677
  _globals['_QUERYPROPOSALSBYGROUPPOLICYREQUEST']._serialized_end=1816
  _globals['_QUERYPROPOSALSBYGROUPPOLICYRESPONSE']._serialized_start=1819
  _globals['_QUERYPROPOSALSBYGROUPPOLICYRESPONSE']._serialized_end=1963
  _globals['_QUERYVOTEBYPROPOSALVOTERREQUEST']._serialized_start=1965
  _globals['_QUERYVOTEBYPROPOSALVOTERREQUEST']._serialized_end=2060
  _globals['_QUERYVOTEBYPROPOSALVOTERRESPONSE']._serialized_start=2062
  _globals['_QUERYVOTEBYPROPOSALVOTERRESPONSE']._serialized_end=2133
  _globals['_QUERYVOTESBYPROPOSALREQUEST']._serialized_start=2135
  _globals['_QUERYVOTESBYPROPOSALREQUEST']._serialized_end=2245
  _globals['_QUERYVOTESBYPROPOSALRESPONSE']._serialized_start=2248
  _globals['_QUERYVOTESBYPROPOSALRESPONSE']._serialized_end=2377
  _globals['_QUERYVOTESBYVOTERREQUEST']._serialized_start=2379
  _globals['_QUERYVOTESBYVOTERREQUEST']._serialized_end=2506
  _globals['_QUERYVOTESBYVOTERRESPONSE']._serialized_start=2508
  _globals['_QUERYVOTESBYVOTERRESPONSE']._serialized_end=2634
  _globals['_QUERYGROUPSBYMEMBERREQUEST']._serialized_start=2637
  _globals['_QUERYGROUPSBYMEMBERREQUEST']._serialized_end=2768
  _globals['_QUERYGROUPSBYMEMBERRESPONSE']._serialized_start=2771
  _globals['_QUERYGROUPSBYMEMBERRESPONSE']._serialized_end=2905
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_start=2907
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_end=2953
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_start=2955
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_end=3037
  _globals['_QUERYGROUPSREQUEST']._serialized_start=3039
  _globals['_QUERYGROUPSREQUEST']._serialized_end=3119
  _globals['_QUERYGROUPSRESPONSE']._serialized_start=3121
  _globals['_QUERYGROUPSRESPONSE']._serialized_end=3247
  _globals['_QUERY']._serialized_start=3250
  _globals['_QUERY']._serialized_end=5549
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n injective/wasmx/v1/genesis.proto\x12\x12injective.wasmx.v1\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a\x14gogoproto/gogo.proto\"u\n\x1dRegisteredContractWithAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x43\n\x13registered_contract\x18\x02 \x01(\x0b\x32&.injective.wasmx.v1.RegisteredContract\"\x97\x01\n\x0cGenesisState\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.wasmx.v1.ParamsB\x04\xc8\xde\x1f\x00\x12U\n\x14registered_contracts\x18\x02 \x03(\x0b\x32\x31.injective.wasmx.v1.RegisteredContractWithAddressB\x04\xc8\xde\x1f\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['registered_contracts']._options = None
  _GENESISSTATE.fields_by_name['registered_contracts']._serialized_options = b'\310\336\037\000'
  _globals['_REGISTEREDCONTRACTWITHADDRESS']._serialized_start=110
  _globals['_REGISTEREDCONTRACTWITHADDRESS']._serialized_end=227
  _globals['_GENESISSTATE']._serialized_start=230
  _globals['_GENESISSTATE']._serialized_end=381
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/commitment/v1/commitment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.ics23.v1 import proofs_pb2 as cosmos_dot_ics23_dot_v1_dot_proofs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ibc/core/commitment/v1/commitment.proto\x12\x16ibc.core.commitment.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmos/ics23/v1/proofs.proto\" \n\nMerkleRoot\x12\x0c\n\x04hash\x18\x01 \x01(\x0c:\x04\x88\xa0\x1f\x00\"9\n\x0cMerklePrefix\x12)\n\nkey_prefix\x18\x01 \x01(\x0c\x42\x15\xf2\xde\x1f\x11yaml:\"key_prefix\"\"9\n\nMerklePath\x12%\n\x08key_path\x18\x01 \x03(\tB\x13\xf2\xde\x1f\x0fyaml:\"key_path\":\x04\x98\xa0\x1f\x00\"?\n\x0bMerkleProof\x12\x30\n\x06proofs\x18\x01 \x03(\x0b\x32 .cosmos.ics23.v1.CommitmentProofB>Z<github.com/cosmos/ibc-go/v7/modules/core/23-commitment/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.commitment.v1.commitment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/cosmos/ibc-go/v7/modules/core/23-commitment/types'
  _MERKLEROOT._options = None
  _MERKLEROOT._serialized_options = b'\210\240\037\000'
  _MERKLEPREFIX.fields_by_name['key_prefix']._options = None
  _MERKLEPREFIX.fields_by_name['key_prefix']._serialized_options = b'\362\336\037\021yaml:\"key_prefix\"'
  _MERKLEPATH.fields_by_name['key_path']._options = None
  _MERKLEPATH.fields_by_name['key_path']._serialized_options = b'\362\336\037\017yaml:\"key_path\"'
  _MERKLEPATH._options = None
  _MERKLEPATH._serialized_options = b'\230\240\037\000'
  _globals['_MERKLEROOT']._serialized_start=119
  _globals['_MERKLEROOT']._serialized_end=151
  _globals['_MERKLEPREFIX']._serialized_start=153
  _globals['_MERKLEPREFIX']._serialized_end=210
  _globals['_MERKLEPATH']._serialized_start=212
  _globals['_MERKLEPATH']._serialized_end=269
  _globals['_MERKLEPROOF']._serialized_start=271
  _globals['_MERKLEPROOF']._serialized_end=334
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.gov.v1 import gov_pb2 as cosmos_dot_gov_dot_v1_dot_gov__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63osmos/gov/v1/tx.proto\x12\rcosmos.gov.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/gov/v1/gov.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x19google/protobuf/any.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\x8b\x02\n\x11MsgSubmitProposal\x12&\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12=\n\x0finitial_deposit\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12*\n\x08proposer\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0f\n\x07summary\x18\x06 \x01(\t:1\x82\xe7\xb0*\x08proposer\x8a\xe7\xb0*\x1f\x63osmos-sdk/v1/MsgSubmitProposal\"0\n\x19MsgSubmitProposalResponse\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"\xa7\x01\n\x14MsgExecLegacyContent\x12\x45\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1e\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x12\x11\n\tauthority\x18\x02 \x01(\t:5\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\"cosmos-sdk/v1/MsgExecLegacyContent\"\x1e\n\x1cMsgExecLegacyContentResponse\"\xc0\x01\n\x07MsgVote\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x06option\x18\x03 \x01(\x0e\x32\x19.cosmos.gov.v1.VoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t:$\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x15\x63osmos-sdk/v1/MsgVote\"\x11\n\x0fMsgVoteResponse\"\xd9\x01\n\x0fMsgVoteWeighted\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x07options\x18\x03 \x03(\x0b\x32!.cosmos.gov.v1.WeightedVoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t:,\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x1d\x63osmos-sdk/v1/MsgVoteWeighted\"\x19\n\x17MsgVoteWeightedResponse\"\xc7\x01\n\nMsgDeposit\x12)\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x14\xea\xde\x1f\x0bproposal_id\xa8\xe7\xb0*\x01\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:+\x82\xe7\xb0*\tdepositor\x8a\xe7\xb0*\x18\x63osmos-sdk/v1/MsgDeposit\"\x14\n\x12MsgDepositResponse\"\xa8\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x15.cosmos.gov.v1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:6\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*#cosmos-sdk/x/gov/v1/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\x8a\x04\n\x03Msg\x12\\\n\x0eSubmitProposal\x12 .cosmos.gov.v1.MsgSubmitProposal\x1a(.cosmos.gov.v1.MsgSubmitProposalResponse\x12\x65\n\x11\x45xecLegacyContent\x12#.cosmos.gov.v1.MsgExecLegacyContent\x1a+.cosmos.gov.v1.MsgExecLegacyContentResponse\x12>\n\x04Vote\x12\x16.cosmos.gov.v1.MsgVote\x1a\x1e.cosmos.gov.v1.MsgVoteResponse\x12V\n\x0cVoteWeighted\x12\x1e.cosmos.gov.v1.MsgVoteWeighted\x1a&.cosmos.gov.v1.MsgVoteWeightedResponse\x12G\n\x07\x44\x65posit\x12\x19.cosmos.gov.v1.MsgDeposit\x1a!.cosmos.gov.v1.MsgDepositResponse\x12V\n\x0cUpdateParams\x12\x1e.cosmos.gov.v1.MsgUpdateParams\x1a&.cosmos.gov.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42-Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1'
  _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._options = None
  _MSGSUBMITPROPOSAL.fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGSUBMITPROPOSAL.fields_by_name['proposer']._options = None
  _MSGSUBMITPROPOSAL.fields_by_name['proposer']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSUBMITPROPOSAL._options = None
  _MSGSUBMITPROPOSAL._serialized_options = b'\202\347\260*\010proposer\212\347\260*\037cosmos-sdk/v1/MsgSubmitProposal'
  _MSGEXECLEGACYCONTENT.fields_by_name['content']._options = None
  _MSGEXECLEGACYCONTENT.fields_by_name['content']._serialized_options = b'\312\264-\032cosmos.gov.v1beta1.Content'
  _MSGEXECLEGACYCONTENT._options = None
  _MSGEXECLEGACYCONTENT._serialized_options = b'\202\347\260*\tauthority\212\347\260*\"cosmos-sdk/v1/MsgExecLegacyContent'
  _MSGVOTE.fields_by_name['proposal_id']._options = None
  _MSGVOTE.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _MSGVOTE.fields_by_name['voter']._options = None
  _MSGVOTE.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGVOTE._options = None
  _MSGVOTE._serialized_options = b'\202\347\260*\005voter\212\347\260*\025cosmos-sdk/v1/MsgVote'
  _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._options = None
  _MSGVOTEWEIGHTED.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _MSGVOTEWEIGHTED.fields_by_name['voter']._options = None
  _MSGVOTEWEIGHTED.fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGVOTEWEIGHTED._options = None
  _MSGVOTEWEIGHTED._serialized_options = b'\202\347\260*\005voter\212\347\260*\035cosmos-sdk/v1/MsgVoteWeighted'
  _MSGDEPOSIT.fields_by_name['proposal_id']._options = None
  _MSGDEPOSIT.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\013proposal_id\250\347\260*\001'
  _MSGDEPOSIT.fields_by_name['depositor']._options = None
  _MSGDEPOSIT.fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGDEPOSIT.fields_by_name['amount']._options = None
  _MSGDEPOSIT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGDEPOSIT._options = None
  _MSGDEPOSIT._serialized_options = b'\202\347\260*\tdepositor\212\347\260*\030cosmos-sdk/v1/MsgDeposit'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority\212\347\260*#cosmos-sdk/x/gov/v1/MsgUpdateParams'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSUBMITPROPOSAL']._serialized_start=219
  _globals['_MSGSUBMITPROPOSAL']._serialized_end=486
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_start=488
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_end=536
  _globals['_MSGEXECLEGACYCONTENT']._serialized_start=539
  _globals['_MSGEXECLEGACYCONTENT']._serialized_end=706
  _globals['_MSGEXECLEGACYCONTENTRESPONSE']._serialized_start=708
  _globals['_MSGEXECLEGACYCONTENTRESPONSE']._serialized_end=738
  _globals['_MSGVOTE']._serialized_start=741
  _globals['_MSGVOTE']._serialized_end=933
  _globals['_MSGVOTERESPONSE']._serialized_start=935
  _globals['_MSGVOTERESPONSE']._serialized_end=952
  _globals['_MSGVOTEWEIGHTED']._serialized_start=955
  _globals['_MSGVOTEWEIGHTED']._serialized_end=1172
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_start=1174
  _globals['_MSGVOTEWEIGHTEDRESPONSE']._serialized_end=1199
  _globals['_MSGDEPOSIT']._serialized_start=1202
  _globals['_MSGDEPOSIT']._serialized_end=1401
  _globals['_MSGDEPOSITRESPONSE']._serialized_start=1403
  _globals['_MSGDEPOSITRESPONSE']._serialized_end=1423
  _globals['_MSGUPDATEPARAMS']._serialized_start=1426
  _globals['_MSGUPDATEPARAMS']._serialized_end=1594
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1596
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1621
  _globals['_MSG']._serialized_start=1624
  _globals['_MSG']._serialized_end=2146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from injective.wasmx.v1 import proposal_pb2 as injective_dot_wasmx_dot_v1_dot_proposal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1binjective/wasmx/v1/tx.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a!injective/wasmx/v1/proposal.proto\"e\n\x18MsgExecuteContractCompat\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05\x66unds\x18\x04 \x01(\t:\x0b\x82\xe7\xb0*\x06sender\"0\n MsgExecuteContractCompatResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x8d\x01\n\x11MsgUpdateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\x12\x11\n\tgas_limit\x18\x03 \x01(\x04\x12\x11\n\tgas_price\x18\x04 \x01(\x04\x12\x1b\n\radmin_address\x18\x05 \x01(\tB\x04\xc8\xde\x1f\x01:\x0b\x82\xe7\xb0*\x06sender\"\x1b\n\x19MsgUpdateContractResponse\"L\n\x13MsgActivateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t:\x0b\x82\xe7\xb0*\x06sender\"\x1d\n\x1bMsgActivateContractResponse\"N\n\x15MsgDeactivateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t:\x0b\x82\xe7\xb0*\x06sender\"\x1f\n\x1dMsgDeactivateContractResponse\"\x80\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x1a.injective.wasmx.v1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse\"\x90\x01\n\x13MsgRegisterContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\\\n\x1d\x63ontract_registration_request\x18\x02 \x01(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00:\x0b\x82\xe7\xb0*\x06sender\"\x1d\n\x1bMsgRegisterContractResponse2\xba\x05\n\x03Msg\x12t\n\x1cUpdateRegistryContractParams\x12%.injective.wasmx.v1.MsgUpdateContract\x1a-.injective.wasmx.v1.MsgUpdateContractResponse\x12t\n\x18\x41\x63tivateRegistryContract\x12\'.injective.wasmx.v1.MsgActivateContract\x1a/.injective.wasmx.v1.MsgActivateContractResponse\x12z\n\x1a\x44\x65\x61\x63tivateRegistryContract\x12).injective.wasmx.v1.MsgDeactivateContract\x1a\x31.injective.wasmx.v1.MsgDeactivateContractResponse\x12{\n\x15\x45xecuteContractCompat\x12,.injective.wasmx.v1.MsgExecuteContractCompat\x1a\x34.injective.wasmx.v1.MsgExecuteContractCompatResponse\x12`\n\x0cUpdateParams\x12#.injective.wasmx.v1.MsgUpdateParams\x1a+.injective.wasmx.v1.MsgUpdateParamsResponse\x12l\n\x10RegisterContract\x12\'.injective.wasmx.v1.MsgRegisterContract\x1a/.injective.wasmx.v1.MsgRegisterContractResponseBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _MSGEXECUTECONTRACTCOMPAT._options = None
  _MSGEXECUTECONTRACTCOMPAT._serialized_options = b'\202\347\260*\006sender'
  _MSGUPDATECONTRACT.fields_by_name['admin_address']._options = None
  _MSGUPDATECONTRACT.fields_by_name['admin_address']._serialized_options = b'\310\336\037\001'
  _MSGUPDATECONTRACT._options = None
  _MSGUPDATECONTRACT._serialized_options = b'\202\347\260*\006sender'
  _MSGACTIVATECONTRACT._options = None
  _MSGACTIVATECONTRACT._serialized_options = b'\202\347\260*\006sender'
  _MSGDEACTIVATECONTRACT._options = None
  _MSGDEACTIVATECONTRACT._serialized_options = b'\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _MSGREGISTERCONTRACT.fields_by_name['contract_registration_request']._options = None
  _MSGREGISTERCONTRACT.fields_by_name['contract_registration_request']._serialized_options = b'\310\336\037\000'
  _MSGREGISTERCONTRACT._options = None
  _MSGREGISTERCONTRACT._serialized_options = b'\202\347\260*\006sender'
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_start=219
  _globals['_MSGEXECUTECONTRACTCOMPAT']._serialized_end=320
  _globals['_MSGEXECUTECONTRACTCOMPATRESPONSE']._serialized_start=322
  _globals['_MSGEXECUTECONTRACTCOMPATRESPONSE']._serialized_end=370
  _globals['_MSGUPDATECONTRACT']._serialized_start=373
  _globals['_MSGUPDATECONTRACT']._serialized_end=514
  _globals['_MSGUPDATECONTRACTRESPONSE']._serialized_start=516
  _globals['_MSGUPDATECONTRACTRESPONSE']._serialized_end=543
  _globals['_MSGACTIVATECONTRACT']._serialized_start=545
  _globals['_MSGACTIVATECONTRACT']._serialized_end=621
  _globals['_MSGACTIVATECONTRACTRESPONSE']._serialized_start=623
  _globals['_MSGACTIVATECONTRACTRESPONSE']._serialized_end=652
  _globals['_MSGDEACTIVATECONTRACT']._serialized_start=654
  _globals['_MSGDEACTIVATECONTRACT']._serialized_end=732
  _globals['_MSGDEACTIVATECONTRACTRESPONSE']._serialized_start=734
  _globals['_MSGDEACTIVATECONTRACTRESPONSE']._serialized_end=765
  _globals['_MSGUPDATEPARAMS']._serialized_start=768
  _globals['_MSGUPDATEPARAMS']._serialized_end=896
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=898
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=923
  _globals['_MSGREGISTERCONTRACT']._serialized_start=926
  _globals['_MSGREGISTERCONTRACT']._serialized_end=1070
  _globals['_MSGREGISTERCONTRACTRESPONSE']._serialized_start=1072
  _globals['_MSGREGISTERCONTRACTRESPONSE']._serialized_end=1101
  _globals['_MSG']._serialized_start=1104
  _globals['_MSG']._serialized_end=1802
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"injective/auction/v1beta1/tx.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\'injective/auction/v1beta1/auction.proto\"q\n\x06MsgBid\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x33\n\nbid_amount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x10\n\x0eMsgBidResponse\"\x87\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xca\x01\n\x03Msg\x12S\n\x03\x42id\x12!.injective.auction.v1beta1.MsgBid\x1a).injective.auction.v1beta1.MsgBidResponse\x12n\n\x0cUpdateParams\x12*.injective.auction.v1beta1.MsgUpdateParams\x1a\x32.injective.auction.v1beta1.MsgUpdateParamsResponseBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types'
  _MSGBID.fields_by_name['bid_amount']._options = None
  _MSGBID.fields_by_name['bid_amount']._serialized_options = b'\310\336\037\000'
  _MSGBID._options = None
  _MSGBID._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGBID']._serialized_start=212
  _globals['_MSGBID']._serialized_end=325
  _globals['_MSGBIDRESPONSE']._serialized_start=327
  _globals['_MSGBIDRESPONSE']._serialized_end=343
  _globals['_MSGUPDATEPARAMS']._serialized_start=346
  _globals['_MSGUPDATEPARAMS']._serialized_end=481
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=483
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=508
  _globals['_MSG']._serialized_start=511
  _globals['_MSG']._serialized_end=713
# @@protoc_insertion_point(module_scope)



import asyncio
from decimal import Decimal

from pyinjective.async_client import AsyncClient
from pyinjective.core.network import Network

metadata_template = """[{}]
description = '{} {} {}'
base = {}
quote = {}
min_price_tick_size = {}
min_display_price_tick_size = {}
min_quantity_tick_size = {}
min_display_quantity_tick_size = {}

"""

symbol_template = """[{}]
peggy_denom = {}
decimals = {}

"""

testnet_denom_output = ""
mainnet_denom_output = ""


async def fetch_denom(network) -> str:
    denom_output = ""

    # fetch meta data for spot markets
    client = AsyncClient(network)
    spot_markets = await client.all_spot_markets()
    for market in spot_markets.values():
        min_display_price_tick_size = market.min_price_tick_size / Decimal(
            f"1e{market.quote_token.decimals - market.base_token.decimals}"
        )
        min_display_quantity_tick_size = market.min_quantity_tick_size / Decimal(f"1e{market.base_token.decimals}")
        config = metadata_template.format(
            market.id,
            network.string().capitalize(),
            "Spot",
            market.ticker,
            market.base_token.decimals,
            market.quote_token.decimals,
            f"{market.min_price_tick_size.normalize():f}",
            f"{min_display_price_tick_size.normalize():f}",
            f"{market.min_quantity_tick_size.normalize():f}",
            f"{min_display_quantity_tick_size.normalize():f}",
        )
        denom_output += config

    # fetch meta data for derivative markets
    client = AsyncClient(network)
    derivative_markets = await client.all_derivative_markets()
    for market in derivative_markets.values():
        min_display_price_tick_size = market.min_price_tick_size / Decimal(f"1e{market.quote_token.decimals}")
        config = metadata_template.format(
            market.id,
            network.string().capitalize(),
            "Derivative",
            market.ticker,
            0,
            market.quote_token.decimals,
            f"{market.min_price_tick_size.normalize():f}",
            f"{min_display_price_tick_size.normalize():f}",
            f"{market.min_quantity_tick_size.normalize():f}",
            f"{market.min_quantity_tick_size.normalize():f}",
        )
        denom_output += config

    tokens = await client.all_tokens()
    for token_symbol, token in sorted(tokens.items(), key=lambda dict_item: dict_item[0]):
        symbol = symbol_template.format(token_symbol, token.denom, token.decimals)
        denom_output += symbol

    return denom_output


async def main() -> None:
    devnet = Network.devnet()
    data = await fetch_denom(devnet)
    with open("../denoms_devnet.ini", "w") as text_file:
        text_file.write(data)

    testnet = Network.testnet()
    data = await fetch_denom(testnet)
    with open("../denoms_testnet.ini", "w") as text_file:
        text_file.write(data)

    mainnet = Network.mainnet()
    data = await fetch_denom(mainnet)
    with open("../denoms_mainnet.ini", "w") as text_file:
        text_file.write(data)


if __name__ == "__main__":
    asyncio.get_event_loop().run_until_complete(main())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/bank/v1beta1/query.proto\x12\x13\x63osmos.bank.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/query/v1/query.proto\x1a\x11\x61mino/amino.proto\"Y\n\x13QueryBalanceRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"B\n\x14QueryBalanceResponse\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"\x8a\x01\n\x17QueryAllBalancesRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbb\x01\n\x18QueryAllBalancesResponse\x12\x62\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x90\x01\n\x1dQuerySpendableBalancesRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xc1\x01\n\x1eQuerySpendableBalancesResponse\x12\x62\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"i\n#QuerySpendableBalanceByDenomRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"R\n$QuerySpendableBalanceByDenomResponse\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"_\n\x17QueryTotalSupplyRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb9\x01\n\x18QueryTotalSupplyResponse\x12`\n\x06supply\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"%\n\x14QuerySupplyOfRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"M\n\x15QuerySupplyOfResponse\x12\x34\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x14\n\x12QueryParamsRequest\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"X\n\x1aQueryDenomsMetadataRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x97\x01\n\x1bQueryDenomsMetadataResponse\x12;\n\tmetadatas\x18\x01 \x03(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"*\n\x19QueryDenomMetadataRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"X\n\x1aQueryDenomMetadataResponse\x12:\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"d\n\x17QueryDenomOwnersRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"n\n\nDenomOwner\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x8e\x01\n\x18QueryDenomOwnersResponse\x12\x35\n\x0c\x64\x65nom_owners\x18\x01 \x03(\x0b\x32\x1f.cosmos.bank.v1beta1.DenomOwner\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"e\n\x17QuerySendEnabledRequest\x12\x0e\n\x06\x64\x65noms\x18\x01 \x03(\t\x12:\n\npagination\x18\x63 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8f\x01\n\x18QuerySendEnabledResponse\x12\x36\n\x0csend_enabled\x18\x01 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabled\x12;\n\npagination\x18\x63 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xb2\x0e\n\x05Query\x12\x9d\x01\n\x07\x42\x61lance\x12(.cosmos.bank.v1beta1.QueryBalanceRequest\x1a).cosmos.bank.v1beta1.QueryBalanceResponse\"=\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/bank/v1beta1/balances/{address}/by_denom\x12\xa0\x01\n\x0b\x41llBalances\x12,.cosmos.bank.v1beta1.QueryAllBalancesRequest\x1a-.cosmos.bank.v1beta1.QueryAllBalancesResponse\"4\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02)\x12\'/cosmos/bank/v1beta1/balances/{address}\x12\xbc\x01\n\x11SpendableBalances\x12\x32.cosmos.bank.v1beta1.QuerySpendableBalancesRequest\x1a\x33.cosmos.bank.v1beta1.QuerySpendableBalancesResponse\">\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x33\x12\x31/cosmos/bank/v1beta1/spendable_balances/{address}\x12\xd7\x01\n\x17SpendableBalanceByDenom\x12\x38.cosmos.bank.v1beta1.QuerySpendableBalanceByDenomRequest\x1a\x39.cosmos.bank.v1beta1.QuerySpendableBalanceByDenomResponse\"G\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02<\x12:/cosmos/bank/v1beta1/spendable_balances/{address}/by_denom\x12\x94\x01\n\x0bTotalSupply\x12,.cosmos.bank.v1beta1.QueryTotalSupplyRequest\x1a-.cosmos.bank.v1beta1.QueryTotalSupplyResponse\"(\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/supply\x12\x94\x01\n\x08SupplyOf\x12).cosmos.bank.v1beta1.QuerySupplyOfRequest\x1a*.cosmos.bank.v1beta1.QuerySupplyOfResponse\"1\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/supply/by_denom\x12\x85\x01\n\x06Params\x12\'.cosmos.bank.v1beta1.QueryParamsRequest\x1a(.cosmos.bank.v1beta1.QueryParamsResponse\"(\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/params\x12\xab\x01\n\rDenomMetadata\x12..cosmos.bank.v1beta1.QueryDenomMetadataRequest\x1a/.cosmos.bank.v1beta1.QueryDenomMetadataResponse\"9\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02.\x12,/cosmos/bank/v1beta1/denoms_metadata/{denom}\x12\xa6\x01\n\x0e\x44\x65nomsMetadata\x12/.cosmos.bank.v1beta1.QueryDenomsMetadataRequest\x1a\x30.cosmos.bank.v1beta1.QueryDenomsMetadataResponse\"1\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/denoms_metadata\x12\xa2\x01\n\x0b\x44\x65nomOwners\x12,.cosmos.bank.v1beta1.QueryDenomOwnersRequest\x1a-.cosmos.bank.v1beta1.QueryDenomOwnersResponse\"6\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02+\x12)/cosmos/bank/v1beta1/denom_owners/{denom}\x12\x9a\x01\n\x0bSendEnabled\x12,.cosmos.bank.v1beta1.QuerySendEnabledRequest\x1a-.cosmos.bank.v1beta1.QuerySendEnabledResponse\".\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02#\x12!/cosmos/bank/v1beta1/send_enabledB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _QUERYBALANCEREQUEST.fields_by_name['address']._options = None
  _QUERYBALANCEREQUEST.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYBALANCEREQUEST._options = None
  _QUERYBALANCEREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYALLBALANCESREQUEST.fields_by_name['address']._options = None
  _QUERYALLBALANCESREQUEST.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYALLBALANCESREQUEST._options = None
  _QUERYALLBALANCESREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYALLBALANCESRESPONSE.fields_by_name['balances']._options = None
  _QUERYALLBALANCESRESPONSE.fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _QUERYSPENDABLEBALANCESREQUEST.fields_by_name['address']._options = None
  _QUERYSPENDABLEBALANCESREQUEST.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYSPENDABLEBALANCESREQUEST._options = None
  _QUERYSPENDABLEBALANCESREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYSPENDABLEBALANCESRESPONSE.fields_by_name['balances']._options = None
  _QUERYSPENDABLEBALANCESRESPONSE.fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _QUERYSPENDABLEBALANCEBYDENOMREQUEST.fields_by_name['address']._options = None
  _QUERYSPENDABLEBALANCEBYDENOMREQUEST.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYSPENDABLEBALANCEBYDENOMREQUEST._options = None
  _QUERYSPENDABLEBALANCEBYDENOMREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYTOTALSUPPLYREQUEST._options = None
  _QUERYTOTALSUPPLYREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYTOTALSUPPLYRESPONSE.fields_by_name['supply']._options = None
  _QUERYTOTALSUPPLYRESPONSE.fields_by_name['supply']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _QUERYSUPPLYOFRESPONSE.fields_by_name['amount']._options = None
  _QUERYSUPPLYOFRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDENOMSMETADATARESPONSE.fields_by_name['metadatas']._options = None
  _QUERYDENOMSMETADATARESPONSE.fields_by_name['metadatas']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDENOMMETADATARESPONSE.fields_by_name['metadata']._options = None
  _QUERYDENOMMETADATARESPONSE.fields_by_name['metadata']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _DENOMOWNER.fields_by_name['address']._options = None
  _DENOMOWNER.fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _DENOMOWNER.fields_by_name['balance']._options = None
  _DENOMOWNER.fields_by_name['balance']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERY.methods_by_name['Balance']._options = None
  _QUERY.methods_by_name['Balance']._serialized_options = b'\210\347\260*\001\202\323\344\223\0022\0220/cosmos/bank/v1beta1/balances/{address}/by_denom'
  _QUERY.methods_by_name['AllBalances']._options = None
  _QUERY.methods_by_name['AllBalances']._serialized_options = b'\210\347\260*\001\202\323\344\223\002)\022\'/cosmos/bank/v1beta1/balances/{address}'
  _QUERY.methods_by_name['SpendableBalances']._options = None
  _QUERY.methods_by_name['SpendableBalances']._serialized_options = b'\210\347\260*\001\202\323\344\223\0023\0221/cosmos/bank/v1beta1/spendable_balances/{address}'
  _QUERY.methods_by_name['SpendableBalanceByDenom']._options = None
  _QUERY.methods_by_name['SpendableBalanceByDenom']._serialized_options = b'\210\347\260*\001\202\323\344\223\002<\022:/cosmos/bank/v1beta1/spendable_balances/{address}/by_denom'
  _QUERY.methods_by_name['TotalSupply']._options = None
  _QUERY.methods_by_name['TotalSupply']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/supply'
  _QUERY.methods_by_name['SupplyOf']._options = None
  _QUERY.methods_by_name['SupplyOf']._serialized_options = b'\210\347\260*\001\202\323\344\223\002&\022$/cosmos/bank/v1beta1/supply/by_denom'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/params'
  _QUERY.methods_by_name['DenomMetadata']._options = None
  _QUERY.methods_by_name['DenomMetadata']._serialized_options = b'\210\347\260*\001\202\323\344\223\002.\022,/cosmos/bank/v1beta1/denoms_metadata/{denom}'
  _QUERY.methods_by_name['DenomsMetadata']._options = None
  _QUERY.methods_by_name['DenomsMetadata']._serialized_options = b'\210\347\260*\001\202\323\344\223\002&\022$/cosmos/bank/v1beta1/denoms_metadata'
  _QUERY.methods_by_name['DenomOwners']._options = None
  _QUERY.methods_by_name['DenomOwners']._serialized_options = b'\210\347\260*\001\202\323\344\223\002+\022)/cosmos/bank/v1beta1/denom_owners/{denom}'
  _QUERY.methods_by_name['SendEnabled']._options = None
  _QUERY.methods_by_name['SendEnabled']._serialized_options = b'\210\347\260*\001\202\323\344\223\002#\022!/cosmos/bank/v1beta1/send_enabled'
  _globals['_QUERYBALANCEREQUEST']._serialized_start=291
  _globals['_QUERYBALANCEREQUEST']._serialized_end=380
  _globals['_QUERYBALANCERESPONSE']._serialized_start=382
  _globals['_QUERYBALANCERESPONSE']._serialized_end=448
  _globals['_QUERYALLBALANCESREQUEST']._serialized_start=451
  _globals['_QUERYALLBALANCESREQUEST']._serialized_end=589
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_start=592
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_end=779
  _globals['_QUERYSPENDABLEBALANCESREQUEST']._serialized_start=782
  _globals['_QUERYSPENDABLEBALANCESREQUEST']._serialized_end=926
  _globals['_QUERYSPENDABLEBALANCESRESPONSE']._serialized_start=929
  _globals['_QUERYSPENDABLEBALANCESRESPONSE']._serialized_end=1122
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST']._serialized_start=1124
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST']._serialized_end=1229
  _globals['_QUERYSPENDABLEBALANCEBYDENOMRESPONSE']._serialized_start=1231
  _globals['_QUERYSPENDABLEBALANCEBYDENOMRESPONSE']._serialized_end=1313
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_start=1315
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_end=1410
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_start=1413
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_end=1598
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_start=1600
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_end=1637
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_start=1639
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_end=1716
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1718
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1738
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1740
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1817
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_start=1819
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_end=1907
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_start=1910
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_end=2061
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_start=2063
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_end=2105
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_start=2107
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_end=2195
  _globals['_QUERYDENOMOWNERSREQUEST']._serialized_start=2197
  _globals['_QUERYDENOMOWNERSREQUEST']._serialized_end=2297
  _globals['_DENOMOWNER']._serialized_start=2299
  _globals['_DENOMOWNER']._serialized_end=2409
  _globals['_QUERYDENOMOWNERSRESPONSE']._serialized_start=2412
  _globals['_QUERYDENOMOWNERSRESPONSE']._serialized_end=2554
  _globals['_QUERYSENDENABLEDREQUEST']._serialized_start=2556
  _globals['_QUERYSENDENABLEDREQUEST']._serialized_end=2657
  _globals['_QUERYSENDENABLEDRESPONSE']._serialized_start=2660
  _globals['_QUERYSENDENABLEDRESPONSE']._serialized_end=2803
  _globals['_QUERY']._serialized_start=2806
  _globals['_QUERY']._serialized_end=4648
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/staking/v1beta1/query.proto\x12\x16\x63osmos.staking.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/staking/v1beta1/staking.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/query/v1/query.proto\x1a\x11\x61mino/amino.proto\"d\n\x16QueryValidatorsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x98\x01\n\x17QueryValidatorsResponse\x12@\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"I\n\x15QueryValidatorRequest\x12\x30\n\x0evalidator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"Y\n\x16QueryValidatorResponse\x12?\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x90\x01\n QueryValidatorDelegationsRequest\x12\x30\n\x0evalidator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xcc\x01\n!QueryValidatorDelegationsResponse\x12j\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB \xc8\xde\x1f\x00\xaa\xdf\x1f\x13\x44\x65legationResponses\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x99\x01\n)QueryValidatorUnbondingDelegationsRequest\x12\x30\n\x0evalidator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xbe\x01\n*QueryValidatorUnbondingDelegationsResponse\x12S\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x86\x01\n\x16QueryDelegationRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x0evalidator_addr\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"b\n\x17QueryDelegationResponse\x12G\n\x13\x64\x65legation_response\x18\x01 \x01(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponse\"\x8f\x01\n\x1fQueryUnbondingDelegationRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x0evalidator_addr\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"j\n QueryUnbondingDelegationResponse\x12\x46\n\x06unbond\x18\x01 \x01(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x9a\x01\n QueryDelegatorDelegationsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb5\x01\n!QueryDelegatorDelegationsResponse\x12S\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xa3\x01\n)QueryDelegatorUnbondingDelegationsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbe\x01\n*QueryDelegatorUnbondingDelegationsResponse\x12S\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xff\x01\n\x19QueryRedelegationsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\x12src_validator_addr\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\x12\x64st_validator_addr\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb2\x01\n\x1aQueryRedelegationsResponse\x12W\n\x16redelegation_responses\x18\x01 \x03(\x0b\x32,.cosmos.staking.v1beta1.RedelegationResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x99\x01\n\x1fQueryDelegatorValidatorsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xa1\x01\n QueryDelegatorValidatorsResponse\x12@\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x8e\x01\n\x1eQueryDelegatorValidatorRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x0evalidator_addr\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"b\n\x1fQueryDelegatorValidatorResponse\x12?\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\",\n\x1aQueryHistoricalInfoRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"S\n\x1bQueryHistoricalInfoResponse\x12\x34\n\x04hist\x18\x01 \x01(\x0b\x32&.cosmos.staking.v1beta1.HistoricalInfo\"\x12\n\x10QueryPoolRequest\"J\n\x11QueryPoolResponse\x12\x35\n\x04pool\x18\x01 \x01(\x0b\x32\x1c.cosmos.staking.v1beta1.PoolB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x14\n\x12QueryParamsRequest\"P\n\x13QueryParamsResponse\x12\x39\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xb0\x16\n\x05Query\x12\x9e\x01\n\nValidators\x12..cosmos.staking.v1beta1.QueryValidatorsRequest\x1a/.cosmos.staking.v1beta1.QueryValidatorsResponse\"/\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02$\x12\"/cosmos/staking/v1beta1/validators\x12\xac\x01\n\tValidator\x12-.cosmos.staking.v1beta1.QueryValidatorRequest\x1a..cosmos.staking.v1beta1.QueryValidatorResponse\"@\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/staking/v1beta1/validators/{validator_addr}\x12\xd9\x01\n\x14ValidatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryValidatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryValidatorDelegationsResponse\"L\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x41\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations\x12\xfe\x01\n\x1dValidatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse\"V\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations\x12\xcc\x01\n\nDelegation\x12..cosmos.staking.v1beta1.QueryDelegationRequest\x1a/.cosmos.staking.v1beta1.QueryDelegationResponse\"]\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}\x12\xfc\x01\n\x13UnbondingDelegation\x12\x37.cosmos.staking.v1beta1.QueryUnbondingDelegationRequest\x1a\x38.cosmos.staking.v1beta1.QueryUnbondingDelegationResponse\"r\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02g\x12\x65/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation\x12\xce\x01\n\x14\x44\x65legatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse\"A\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/staking/v1beta1/delegations/{delegator_addr}\x12\xfe\x01\n\x1d\x44\x65legatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse\"V\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations\x12\xc6\x01\n\rRedelegations\x12\x31.cosmos.staking.v1beta1.QueryRedelegationsRequest\x1a\x32.cosmos.staking.v1beta1.QueryRedelegationsResponse\"N\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x43\x12\x41/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations\x12\xd5\x01\n\x13\x44\x65legatorValidators\x12\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest\x1a\x38.cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse\"K\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators\x12\xe3\x01\n\x12\x44\x65legatorValidator\x12\x36.cosmos.staking.v1beta1.QueryDelegatorValidatorRequest\x1a\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorResponse\"\\\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}\x12\xb8\x01\n\x0eHistoricalInfo\x12\x32.cosmos.staking.v1beta1.QueryHistoricalInfoRequest\x1a\x33.cosmos.staking.v1beta1.QueryHistoricalInfoResponse\"=\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/staking/v1beta1/historical_info/{height}\x12\x86\x01\n\x04Pool\x12(.cosmos.staking.v1beta1.QueryPoolRequest\x1a).cosmos.staking.v1beta1.QueryPoolResponse\")\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool\x12\x8e\x01\n\x06Params\x12*.cosmos.staking.v1beta1.QueryParamsRequest\x1a+.cosmos.staking.v1beta1.QueryParamsResponse\"+\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/paramsB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _QUERYVALIDATORSRESPONSE.fields_by_name['validators']._options = None
  _QUERYVALIDATORSRESPONSE.fields_by_name['validators']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYVALIDATORREQUEST.fields_by_name['validator_addr']._options = None
  _QUERYVALIDATORREQUEST.fields_by_name['validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYVALIDATORRESPONSE.fields_by_name['validator']._options = None
  _QUERYVALIDATORRESPONSE.fields_by_name['validator']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYVALIDATORDELEGATIONSREQUEST.fields_by_name['validator_addr']._options = None
  _QUERYVALIDATORDELEGATIONSREQUEST.fields_by_name['validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
  _QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\252\337\037\023DelegationResponses\250\347\260*\001'
  _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST.fields_by_name['validator_addr']._options = None
  _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST.fields_by_name['validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
  _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDELEGATIONREQUEST.fields_by_name['delegator_addr']._options = None
  _QUERYDELEGATIONREQUEST.fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDELEGATIONREQUEST.fields_by_name['validator_addr']._options = None
  _QUERYDELEGATIONREQUEST.fields_by_name['validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDELEGATIONREQUEST._options = None
  _QUERYDELEGATIONREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYUNBONDINGDELEGATIONREQUEST.fields_by_name['delegator_addr']._options = None
  _QUERYUNBONDINGDELEGATIONREQUEST.fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYUNBONDINGDELEGATIONREQUEST.fields_by_name['validator_addr']._options = None
  _QUERYUNBONDINGDELEGATIONREQUEST.fields_by_name['validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYUNBONDINGDELEGATIONREQUEST._options = None
  _QUERYUNBONDINGDELEGATIONREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond']._options = None
  _QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDELEGATORDELEGATIONSREQUEST.fields_by_name['delegator_addr']._options = None
  _QUERYDELEGATORDELEGATIONSREQUEST.fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDELEGATORDELEGATIONSREQUEST._options = None
  _QUERYDELEGATORDELEGATIONSREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
  _QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST.fields_by_name['delegator_addr']._options = None
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST.fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._options = None
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
  _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYREDELEGATIONSREQUEST.fields_by_name['delegator_addr']._options = None
  _QUERYREDELEGATIONSREQUEST.fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYREDELEGATIONSREQUEST.fields_by_name['src_validator_addr']._options = None
  _QUERYREDELEGATIONSREQUEST.fields_by_name['src_validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYREDELEGATIONSREQUEST.fields_by_name['dst_validator_addr']._options = None
  _QUERYREDELEGATIONSREQUEST.fields_by_name['dst_validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYREDELEGATIONSREQUEST._options = None
  _QUERYREDELEGATIONSREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses']._options = None
  _QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDELEGATORVALIDATORSREQUEST.fields_by_name['delegator_addr']._options = None
  _QUERYDELEGATORVALIDATORSREQUEST.fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDELEGATORVALIDATORSREQUEST._options = None
  _QUERYDELEGATORVALIDATORSREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators']._options = None
  _QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYDELEGATORVALIDATORREQUEST.fields_by_name['delegator_addr']._options = None
  _QUERYDELEGATORVALIDATORREQUEST.fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDELEGATORVALIDATORREQUEST.fields_by_name['validator_addr']._options = None
  _QUERYDELEGATORVALIDATORREQUEST.fields_by_name['validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _QUERYDELEGATORVALIDATORREQUEST._options = None
  _QUERYDELEGATORVALIDATORREQUEST._serialized_options = b'\210\240\037\000\350\240\037\000'
  _QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator']._options = None
  _QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPOOLRESPONSE.fields_by_name['pool']._options = None
  _QUERYPOOLRESPONSE.fields_by_name['pool']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _QUERY.methods_by_name['Validators']._options = None
  _QUERY.methods_by_name['Validators']._serialized_options = b'\210\347\260*\001\202\323\344\223\002$\022\"/cosmos/staking/v1beta1/validators'
  _QUERY.methods_by_name['Validator']._options = None
  _QUERY.methods_by_name['Validator']._serialized_options = b'\210\347\260*\001\202\323\344\223\0025\0223/cosmos/staking/v1beta1/validators/{validator_addr}'
  _QUERY.methods_by_name['ValidatorDelegations']._options = None
  _QUERY.methods_by_name['ValidatorDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002A\022?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations'
  _QUERY.methods_by_name['ValidatorUnbondingDelegations']._options = None
  _QUERY.methods_by_name['ValidatorUnbondingDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002K\022I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations'
  _QUERY.methods_by_name['Delegation']._options = None
  _QUERY.methods_by_name['Delegation']._serialized_options = b'\210\347\260*\001\202\323\344\223\002R\022P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}'
  _QUERY.methods_by_name['UnbondingDelegation']._options = None
  _QUERY.methods_by_name['UnbondingDelegation']._serialized_options = b'\210\347\260*\001\202\323\344\223\002g\022e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation'
  _QUERY.methods_by_name['DelegatorDelegations']._options = None
  _QUERY.methods_by_name['DelegatorDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\0026\0224/cosmos/staking/v1beta1/delegations/{delegator_addr}'
  _QUERY.methods_by_name['DelegatorUnbondingDelegations']._options = None
  _QUERY.methods_by_name['DelegatorUnbondingDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002K\022I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations'
  _QUERY.methods_by_name['Redelegations']._options = None
  _QUERY.methods_by_name['Redelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002C\022A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations'
  _QUERY.methods_by_name['DelegatorValidators']._options = None
  _QUERY.methods_by_name['DelegatorValidators']._serialized_options = b'\210\347\260*\001\202\323\344\223\002@\022>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators'
  _QUERY.methods_by_name['DelegatorValidator']._options = None
  _QUERY.methods_by_name['DelegatorValidator']._serialized_options = b'\210\347\260*\001\202\323\344\223\002Q\022O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}'
  _QUERY.methods_by_name['HistoricalInfo']._options = None
  _QUERY.methods_by_name['HistoricalInfo']._serialized_options = b'\210\347\260*\001\202\323\344\223\0022\0220/cosmos/staking/v1beta1/historical_info/{height}'
  _QUERY.methods_by_name['Pool']._options = None
  _QUERY.methods_by_name['Pool']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\036\022\034/cosmos/staking/v1beta1/pool'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\210\347\260*\001\202\323\344\223\002 \022\036/cosmos/staking/v1beta1/params'
  _globals['_QUERYVALIDATORSREQUEST']._serialized_start=271
  _globals['_QUERYVALIDATORSREQUEST']._serialized_end=371
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_start=374
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_end=526
  _globals['_QUERYVALIDATORREQUEST']._serialized_start=528
  _globals['_QUERYVALIDATORREQUEST']._serialized_end=601
  _globals['_QUERYVALIDATORRESPONSE']._serialized_start=603
  _globals['_QUERYVALIDATORRESPONSE']._serialized_end=692
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_start=695
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_end=839
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_start=842
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_end=1046
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=1049
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=1202
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=1205
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=1395
  _globals['_QUERYDELEGATIONREQUEST']._serialized_start=1398
  _globals['_QUERYDELEGATIONREQUEST']._serialized_end=1532
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_start=1534
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_end=1632
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_start=1635
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_end=1778
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_start=1780
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_end=1886
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_start=1889
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_end=2043
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_start=2046
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_end=2227
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=2230
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=2393
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=2396
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=2586
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_start=2589
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_end=2844
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_start=2847
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_end=3025
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_start=3028
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_end=3181
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_start=3184
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_end=3345
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_start=3348
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_end=3490
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_start=3492
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_end=3590
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_start=3592
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_end=3636
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_start=3638
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_end=3721
  _globals['_QUERYPOOLREQUEST']._serialized_start=3723
  _globals['_QUERYPOOLREQUEST']._serialized_end=3741
  _globals['_QUERYPOOLRESPONSE']._serialized_start=3743
  _globals['_QUERYPOOLRESPONSE']._serialized_end=3817
  _globals['_QUERYPARAMSREQUEST']._serialized_start=3819
  _globals['_QUERYPARAMSREQUEST']._serialized_end=3839
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=3841
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=3921
  _globals['_QUERY']._serialized_start=3924
  _globals['_QUERY']._serialized_end=6788
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: testpb/bank_query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from testpb import bank_pb2 as testpb_dot_bank__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17testpb/bank_query.proto\x12\x06testpb\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x11testpb/bank.proto\"3\n\x11GetBalanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"4\n\x12GetBalanceResponse\x12\x1e\n\x05value\x18\x01 \x01(\x0b\x32\x0f.testpb.Balance\"\xd8\x04\n\x12ListBalanceRequest\x12;\n\x0cprefix_query\x18\x01 \x01(\x0b\x32#.testpb.ListBalanceRequest.IndexKeyH\x00\x12<\n\x0brange_query\x18\x02 \x01(\x0b\x32%.testpb.ListBalanceRequest.RangeQueryH\x00\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1a\x8f\x02\n\x08IndexKey\x12I\n\raddress_denom\x18\x01 \x01(\x0b\x32\x30.testpb.ListBalanceRequest.IndexKey.AddressDenomH\x00\x12:\n\x05\x64\x65nom\x18\x02 \x01(\x0b\x32).testpb.ListBalanceRequest.IndexKey.DenomH\x00\x1aN\n\x0c\x41\x64\x64ressDenom\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x64\x65nom\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_addressB\x08\n\x06_denom\x1a%\n\x05\x44\x65nom\x12\x12\n\x05\x64\x65nom\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_denomB\x05\n\x03key\x1ap\n\nRangeQuery\x12\x31\n\x04\x66rom\x18\x01 \x01(\x0b\x32#.testpb.ListBalanceRequest.IndexKey\x12/\n\x02to\x18\x02 \x01(\x0b\x32#.testpb.ListBalanceRequest.IndexKeyB\x07\n\x05query\"s\n\x13ListBalanceResponse\x12\x1f\n\x06values\x18\x01 \x03(\x0b\x32\x0f.testpb.Balance\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"!\n\x10GetSupplyRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"2\n\x11GetSupplyResponse\x12\x1d\n\x05value\x18\x01 \x01(\x0b\x32\x0e.testpb.Supply\"\xb6\x03\n\x11ListSupplyRequest\x12:\n\x0cprefix_query\x18\x01 \x01(\x0b\x32\".testpb.ListSupplyRequest.IndexKeyH\x00\x12;\n\x0brange_query\x18\x02 \x01(\x0b\x32$.testpb.ListSupplyRequest.RangeQueryH\x00\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x1as\n\x08IndexKey\x12\x39\n\x05\x64\x65nom\x18\x01 \x01(\x0b\x32(.testpb.ListSupplyRequest.IndexKey.DenomH\x00\x1a%\n\x05\x44\x65nom\x12\x12\n\x05\x64\x65nom\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_denomB\x05\n\x03key\x1an\n\nRangeQuery\x12\x30\n\x04\x66rom\x18\x01 \x01(\x0b\x32\".testpb.ListSupplyRequest.IndexKey\x12.\n\x02to\x18\x02 \x01(\x0b\x32\".testpb.ListSupplyRequest.IndexKeyB\x07\n\x05query\"q\n\x12ListSupplyResponse\x12\x1e\n\x06values\x18\x01 \x03(\x0b\x32\x0e.testpb.Supply\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xae\x02\n\x10\x42\x61nkQueryService\x12\x45\n\nGetBalance\x12\x19.testpb.GetBalanceRequest\x1a\x1a.testpb.GetBalanceResponse\"\x00\x12H\n\x0bListBalance\x12\x1a.testpb.ListBalanceRequest\x1a\x1b.testpb.ListBalanceResponse\"\x00\x12\x42\n\tGetSupply\x12\x18.testpb.GetSupplyRequest\x1a\x19.testpb.GetSupplyResponse\"\x00\x12\x45\n\nListSupply\x12\x19.testpb.ListSupplyRequest\x1a\x1a.testpb.ListSupplyResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'testpb.bank_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETBALANCEREQUEST']._serialized_start=98
  _globals['_GETBALANCEREQUEST']._serialized_end=149
  _globals['_GETBALANCERESPONSE']._serialized_start=151
  _globals['_GETBALANCERESPONSE']._serialized_end=203
  _globals['_LISTBALANCEREQUEST']._serialized_start=206
  _globals['_LISTBALANCEREQUEST']._serialized_end=806
  _globals['_LISTBALANCEREQUEST_INDEXKEY']._serialized_start=412
  _globals['_LISTBALANCEREQUEST_INDEXKEY']._serialized_end=683
  _globals['_LISTBALANCEREQUEST_INDEXKEY_ADDRESSDENOM']._serialized_start=559
  _globals['_LISTBALANCEREQUEST_INDEXKEY_ADDRESSDENOM']._serialized_end=637
  _globals['_LISTBALANCEREQUEST_INDEXKEY_DENOM']._serialized_start=639
  _globals['_LISTBALANCEREQUEST_INDEXKEY_DENOM']._serialized_end=676
  _globals['_LISTBALANCEREQUEST_RANGEQUERY']._serialized_start=685
  _globals['_LISTBALANCEREQUEST_RANGEQUERY']._serialized_end=797
  _globals['_LISTBALANCERESPONSE']._serialized_start=808
  _globals['_LISTBALANCERESPONSE']._serialized_end=923
  _globals['_GETSUPPLYREQUEST']._serialized_start=925
  _globals['_GETSUPPLYREQUEST']._serialized_end=958
  _globals['_GETSUPPLYRESPONSE']._serialized_start=960
  _globals['_GETSUPPLYRESPONSE']._serialized_end=1010
  _globals['_LISTSUPPLYREQUEST']._serialized_start=1013
  _globals['_LISTSUPPLYREQUEST']._serialized_end=1451
  _globals['_LISTSUPPLYREQUEST_INDEXKEY']._serialized_start=1215
  _globals['_LISTSUPPLYREQUEST_INDEXKEY']._serialized_end=1330
  _globals['_LISTSUPPLYREQUEST_INDEXKEY_DENOM']._serialized_start=639
  _globals['_LISTSUPPLYREQUEST_INDEXKEY_DENOM']._serialized_end=676
  _globals['_LISTSUPPLYREQUEST_RANGEQUERY']._serialized_start=1332
  _globals['_LISTSUPPLYREQUEST_RANGEQUERY']._serialized_end=1442
  _globals['_LISTSUPPLYRESPONSE']._serialized_start=1453
  _globals['_LISTSUPPLYRESPONSE']._serialized_end=1566
  _globals['_BANKQUERYSERVICE']._serialized_start=1569
  _globals['_BANKQUERYSERVICE']._serialized_end=1871
# @@protoc_insertion_point(module_scope)
